@@ -27,6 +27,8 @@ class Product(ValueBased, Enum):
     CANVAS = 21
     DUST_JACKET = 36
     SAMPLE_PACK = 37
+    STICKER_SHEETS = 38
+    STICKER_ROLLS = 39
 
     def get_value(self) -> int:
         return int(self.value)
