@@ -14,7 +14,6 @@ from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 
 
 class Binding(BaseModel):
-
     FIELDS: ClassVar[Dict[str, str]] = {
         "type": "t",
         "edge": "e",
@@ -24,16 +23,20 @@ class Binding(BaseModel):
         "head_and_tail_bands": "b",
     }
 
-    type: Annotated[BindingType, enum_by_name_or_value(BindingType), enum_dump_name] = Field(
-        default=BindingType.STAPLED,
-        description="Type of binding",
-        json_schema_extra=member_meta(FIELDS["type"]),
+    type: Annotated[BindingType, enum_by_name_or_value(BindingType), enum_dump_name] = (
+        Field(
+            default=BindingType.STAPLED,
+            description="Type of binding",
+            json_schema_extra=member_meta(FIELDS["type"]),
+        )
     )
 
-    edge: Annotated[BindingEdge, enum_by_name_or_value(BindingEdge), enum_dump_name] = Field(
-        default=BindingEdge.LEFT_RIGHT,
-        description="Edge where the binding is applied",
-        json_schema_extra=member_meta(FIELDS["edge"]),
+    edge: Annotated[BindingEdge, enum_by_name_or_value(BindingEdge), enum_dump_name] = (
+        Field(
+            default=BindingEdge.LEFT_RIGHT,
+            description="Edge where the binding is applied",
+            json_schema_extra=member_meta(FIELDS["edge"]),
+        )
     )
 
     sewn: bool = Field(
@@ -42,19 +45,25 @@ class Binding(BaseModel):
         json_schema_extra=member_meta(FIELDS["sewn"]),
     )
 
-    colour: Annotated[BindingColour, enum_by_name_or_value(BindingColour), enum_dump_name] = Field(
+    colour: Annotated[
+        BindingColour, enum_by_name_or_value(BindingColour), enum_dump_name
+    ] = Field(
         default=BindingColour.BLACK,
         description="Colour of the binding wire",
         json_schema_extra=member_meta(FIELDS["colour"]),
     )
 
-    loops: Annotated[BindingLoops, enum_by_name_or_value(BindingLoops), enum_dump_name] = Field(
+    loops: Annotated[
+        BindingLoops, enum_by_name_or_value(BindingLoops), enum_dump_name
+    ] = Field(
         default=BindingLoops.TWO_LOOPS,
         description="Number of loops in the binding",
         json_schema_extra=member_meta(FIELDS["loops"]),
     )
 
-    head_and_tail_bands: Annotated[HeadAndTailBands, enum_by_name_or_value(HeadAndTailBands), enum_dump_name] = Field(
+    head_and_tail_bands: Annotated[
+        HeadAndTailBands, enum_by_name_or_value(HeadAndTailBands), enum_dump_name
+    ] = Field(
         default=HeadAndTailBands.NONE,
         alias="headAndTailBands",
         description="Head and tail band colour for a case bound book",
@@ -66,6 +75,5 @@ class Binding(BaseModel):
         extra="ignore",
         frozen=False,
         strict=True,
-        validate_assignment=True
+        validate_assignment=True,
     )
-
