@@ -1,9 +1,8 @@
 from __future__ import annotations
 
-from typing import ClassVar, Dict, Annotated
-
+from typing import ClassVar, Dict, Annotated, TypeVar, Self, cast
 from pydantic import BaseModel, Field, ConfigDict
-
+from mixam_sdk.item_specification.enums.component_type import ComponentType
 from mixam_sdk.item_specification.enums.colours import Colours
 from mixam_sdk.item_specification.enums.orientation import Orientation
 from mixam_sdk.item_specification.enums.pre_drilled_holes import PreDrilledHoles
@@ -15,16 +14,20 @@ from mixam_sdk.item_specification.interfaces.component_protocol import (
     LaminatedComponent as ILaminatedComponent,
     TwoSidedComponent as ITwoSidedComponent,
     FoiledComponent as IFoiledComponent,
-    ShapedComponent as IShapedComponent, )
+    ShapedComponent as IShapedComponent,
+)
 from mixam_sdk.item_specification.models.custom_size import CustomSize
 from mixam_sdk.item_specification.models.embellishments import Embellishments
 from mixam_sdk.item_specification.models.substrate import Substrate
 from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 from mixam_sdk.utils.utils import MM_IN_INCH
+from functools import cache
+from mixam_sdk.ai_bridge import text_based, to_text_based
+
+T = TypeVar("T", bound=BaseModel)
 
 
 class ComponentSupport(BaseModel):
-
     FIELDS: ClassVar[Dict[str, str]] = {
         "format": "f",
         "standard_size": "z",
@@ -44,7 +47,9 @@ class ComponentSupport(BaseModel):
         json_schema_extra=member_meta(FIELDS["format"]),
     )
 
-    standard_size: Annotated[StandardSize, enum_by_name_or_value(StandardSize), enum_dump_name] = Field(
+    standard_size: Annotated[
+        StandardSize, enum_by_name_or_value(StandardSize), enum_dump_name
+    ] = Field(
         default=StandardSize.NONE,
         alias="standardSize",
         description="Non-DIN standard size; NONE when DIN format is used.",
@@ -58,7 +63,9 @@ class ComponentSupport(BaseModel):
         json_schema_extra=container_meta(FIELDS["custom_size"]),
     )
 
-    orientation: Annotated[Orientation, enum_by_name_or_value(Orientation), enum_dump_name] = Field(
+    orientation: Annotated[
+        Orientation, enum_by_name_or_value(Orientation), enum_dump_name
+    ] = Field(
         default=Orientation.PORTRAIT,
         description="Orientation of the component.",
         json_schema_extra=member_meta(FIELDS["orientation"]),
@@ -77,7 +84,9 @@ class ComponentSupport(BaseModel):
     )
 
     # Note: not all components support pre-drilled holes; keep optional
-    pre_drilled_holes: Annotated[PreDrilledHoles | None, enum_by_name_or_value(PreDrilledHoles), enum_dump_name] = Field(
+    pre_drilled_holes: Annotated[
+        PreDrilledHoles | None, enum_by_name_or_value(PreDrilledHoles), enum_dump_name
+    ] = Field(
         default=PreDrilledHoles.NONE,
         alias="preDrilledHoles",
         description="Pre-drilled holes option (if supported).",
@@ -96,7 +105,7 @@ class ComponentSupport(BaseModel):
         extra="ignore",
         frozen=False,
         strict=True,
-        validate_assignment=True
+        validate_assignment=True,
     )
 
     def has_back(self) -> bool:
@@ -143,8 +152,39 @@ class ComponentSupport(BaseModel):
             height_mm = float(custom_size.height)
 
         from mixam_sdk.utils.utils import get_b_format_from_custom_size
-        fmt = get_b_format_from_custom_size(width=width_mm, height=height_mm, size_format=UnitFormat.METRIC, is_offset_optimized=False, is_perfect_bound=False)
+
+        fmt = get_b_format_from_custom_size(
+            width=width_mm,
+            height=height_mm,
+            size_format=UnitFormat.METRIC,
+            is_offset_optimized=False,
+            is_perfect_bound=False,
+        )
         self.format = int(fmt)
         self.standard_size = StandardSize.NONE
         self.custom_size = custom_size
 
+    @classmethod
+    @cache
+    def text_based(cls: type[T]) -> type[T]:
+        return text_based(cls)
+
+    @classmethod
+    def from_text_based(cls: type[Self], text_based: Self) -> Self:
+        return cls.model_validate(
+            text_based.model_dump(mode="json")
+            | {"component_type": text_based.component_type}
+        )
+
+    def to_text_based(self) -> Self:
+        text_based_cls = type(self).text_based()
+        new_obj = {}
+        for name, field in self.model_dump().items():
+            new_obj[name] = to_text_based(field)
+        return text_based_cls.model_validate(new_obj)
+
+    def to_value_based(self):
+        return cast(
+            ComponentSupport,
+            cast(ComponentType, self.component_type).get_component_class(),
+        ).from_text_based(self)
