@@ -14,6 +14,8 @@ class EnvelopeComponent(LaminatedFoiledComponentSupport):
 
     component_type: Literal[ComponentType.ENVELOPE] = Field(
         default=ComponentType.ENVELOPE,
+        alias="componentType",
+        validation_alias="componentType",
         frozen=True
     )
 
