@@ -19,6 +19,8 @@ class FlatComponent(TwoSidedComponentSupport):
 
     component_type: Literal[ComponentType.FLAT] = Field(
         default=ComponentType.FLAT,
+        alias="componentType",
+        validation_alias="componentType",
         frozen=True
     )
 
