@@ -5,12 +5,12 @@ from typing import Annotated
 from pydantic import BaseModel, Field, ConfigDict
 
 from mixam_sdk.item_specification.enums.binding_colour import BindingColour
-from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 
 
 class BindingColourOption(BaseModel):
 
-    binding_colour: Annotated[BindingColour, enum_by_name(BindingColour), enum_dump_name] = Field(
+    binding_colour: Annotated[BindingColour, enum_by_name_or_value(BindingColour), enum_dump_name] = Field(
         alias="bindingColour",
     )
 
