@@ -5,12 +5,12 @@ from typing import Annotated
 from pydantic import BaseModel, Field, ConfigDict
 
 from mixam_sdk.item_specification.enums.head_and_tail_bands import HeadAndTailBands
-from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 
 
 class HeadAndTailBandMetadata(BaseModel):
 
-    head_and_tail_bands: Annotated[HeadAndTailBands, enum_by_name(HeadAndTailBands), enum_dump_name] = Field(
+    head_and_tail_bands: Annotated[HeadAndTailBands, enum_by_name_or_value(HeadAndTailBands), enum_dump_name] = Field(
         alias="headAndTailBands",
     )
 
