@@ -5,12 +5,12 @@ from typing import Annotated
 from pydantic import BaseModel, Field, ConfigDict
 
 from mixam_sdk.item_specification.enums.binding_type import BindingType
-from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 
 
 class PageCountMetadata(BaseModel):
 
-    binding_type: Annotated[BindingType, enum_by_name(BindingType), enum_dump_name] = Field(
+    binding_type: Annotated[BindingType, enum_by_name_or_value(BindingType), enum_dump_name] = Field(
         alias="bindingType",
     )
 
