@@ -5,12 +5,12 @@ from typing import Annotated
 from pydantic import BaseModel, Field, ConfigDict
 
 from mixam_sdk.item_specification.enums.ribbon_colour import RibbonColour
-from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 
 
 class RibbonMetadata(BaseModel):
 
-    ribbon_colour: Annotated[RibbonColour, enum_by_name(RibbonColour), enum_dump_name] = Field(
+    ribbon_colour: Annotated[RibbonColour, enum_by_name_or_value(RibbonColour), enum_dump_name] = Field(
         alias="ribbonColour",
     )
 
