@@ -5,13 +5,14 @@ from typing import Annotated
 from pydantic import BaseModel, Field, ConfigDict
 
 from mixam_sdk.item_specification.enums.standard_size import StandardSize
-from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 from .folding_options import FoldingOptions
+from .shape_option import ShapeOption
 
 
 class StandardSizeMetadata(BaseModel):
 
-    standard_size: Annotated[StandardSize, enum_by_name(StandardSize), enum_dump_name] = Field(
+    standard_size: Annotated[StandardSize, enum_by_name_or_value(StandardSize), enum_dump_name] = Field(
         alias="standardSize",
     )
 
@@ -53,6 +54,11 @@ class StandardSizeMetadata(BaseModel):
         alias="foldingOptions",
     )
 
+    shape_options: list[ShapeOption] | None = Field(
+        default=None,
+        alias="shapeOptions",
+    )
+
     model_config = ConfigDict(
         populate_by_name=True,
         extra="ignore",
@@ -61,5 +67,4 @@ class StandardSizeMetadata(BaseModel):
         validate_assignment=True,
     )
 
-
 __all__ = ["StandardSizeMetadata"]
